@@ -1,8 +1,8 @@
 package HTML::Feature::Engine;
 use strict;
 use warnings;
-use base qw/Class::Accessor::Fast/;
-__PACKAGE__->mk_accessors(qw/text title desc element/);
+#use base qw/Class::Accessor::Fast/;
+#__PACKAGE__->mk_accessors(qw/text title desc element/);
 
 sub new {
     my $class = shift;
